@@ -1,3 +1,4 @@
+# frozen_string_literal: false
 require "bigdecimal/ludcmp"
 require "bigdecimal/jacobian"
 
@@ -18,7 +19,7 @@ require "bigdecimal/jacobian"
 #
 # f.zero:: returns 0.0
 # f.one:: returns 1.0
-# f.two:: returns 1.0
+# f.two:: returns 2.0
 # f.ten:: returns 10.0
 #
 # f.eps:: returns the convergence criterion (epsilon value) used to determine whether two values are considered equal. If |a-b| < epsilon, the two values are considered equal.
@@ -30,7 +31,7 @@ module Newton
   include Jacobian
   module_function
 
-  def norm(fv,zero=0.0)
+  def norm(fv,zero=0.0) # :nodoc:
     s = zero
     n = fv.size
     for i in 0...n do
@@ -39,6 +40,7 @@ module Newton
     s
   end
 
+  # See also Newton
   def nlsolve(f,x)
     nRetry = 0
     n = x.size
