@@ -11,9 +11,10 @@ module Bundler
 
       protected :original_path
 
-      DEFAULT_GLOB = "{,*,*/*}.gemspec".freeze
+      DEFAULT_GLOB = "{,*,*/*}.gemspec"
 
       def initialize(options)
+        @checksum_store = Checksum::Store.new
         @options = options.dup
         @glob = options["glob"] || DEFAULT_GLOB
 
@@ -85,7 +86,7 @@ module Bundler
         using_message = "Using #{version_message(spec, options[:previous_spec])} from #{self}"
         using_message += " and installing its executables" unless spec.executables.empty?
         print_using_message using_message
-        generate_bin(spec, :disable_extensions => true)
+        generate_bin(spec, disable_extensions: true)
         nil # no post-install message
       end
 
@@ -224,22 +225,22 @@ module Bundler
 
         # Some gem authors put absolute paths in their gemspec
         # and we have to save them from themselves
-        spec.files = spec.files.map do |p|
-          next p unless p =~ /\A#{Pathname::SEPARATOR_PAT}/
-          next if File.directory?(p)
+        spec.files = spec.files.map do |path|
+          next path unless /\A#{Pathname::SEPARATOR_PAT}/o.match?(path)
+          next if File.directory?(path)
           begin
-            Pathname.new(p).relative_path_from(gem_dir).to_s
+            Pathname.new(path).relative_path_from(gem_dir).to_s
           rescue ArgumentError
-            p
+            path
           end
         end.compact
 
         installer = Path::Installer.new(
           spec,
-          :env_shebang => false,
-          :disable_extensions => options[:disable_extensions],
-          :build_args => options[:build_args],
-          :bundler_extension_cache_path => extension_cache_path(spec)
+          env_shebang: false,
+          disable_extensions: options[:disable_extensions],
+          build_args: options[:build_args],
+          bundler_extension_cache_path: extension_cache_path(spec)
         )
         installer.post_install
       rescue Gem::InvalidSpecificationException => e
