@@ -9,28 +9,28 @@
 # lost the next time ruby is built.
 
 module RbConfig
-  RUBY_VERSION.start_with?("3.2.") or
-    raise "ruby lib version (3.2.9) doesn't match executable version (#{RUBY_VERSION})"
+  RUBY_VERSION.start_with?("3.3.") or
+    raise "ruby lib version (3.3.0) doesn't match executable version (#{RUBY_VERSION})"
 
   # Ruby installed directory.
-  TOPDIR = File.dirname(__FILE__).chomp!("/lib/ruby/3.2/riscv64-openbsd")
+  TOPDIR = File.dirname(__FILE__).chomp!("/lib/ruby/3.3/riscv64-openbsd")
   # DESTDIR on make install.
   DESTDIR = '' unless defined? DESTDIR
   # The hash configurations stored.
   CONFIG = {}
   CONFIG["DESTDIR"] = DESTDIR
   CONFIG["MAJOR"] = "3"
-  CONFIG["MINOR"] = "2"
-  CONFIG["TEENY"] = "9"
-  CONFIG["PATCHLEVEL"] = "265"
-  CONFIG["INSTALL"] = '/local/pobj/ruby-3.2.9/bin/install -c'
+  CONFIG["MINOR"] = "3"
+  CONFIG["TEENY"] = "0"
+  CONFIG["PATCHLEVEL"] = "0"
+  CONFIG["INSTALL"] = '/local/pobj/ruby-3.3.0/bin/install -c'
   CONFIG["EXEEXT"] = ""
   CONFIG["prefix"] = (TOPDIR || DESTDIR + "/usr/local")
-  CONFIG["ruby_install_name"] = "$(RUBY_BASE_NAME)32"
-  CONFIG["RUBY_INSTALL_NAME"] = "$(RUBY_BASE_NAME)32"
-  CONFIG["RUBY_SO_NAME"] = "ruby32"
+  CONFIG["ruby_install_name"] = "$(RUBY_BASE_NAME)33"
+  CONFIG["RUBY_INSTALL_NAME"] = "$(RUBY_BASE_NAME)33"
+  CONFIG["RUBY_SO_NAME"] = "ruby33"
   CONFIG["exec"] = "exec"
-  CONFIG["ruby_pc"] = "ruby-3.2.pc"
+  CONFIG["ruby_pc"] = "ruby-3.3.pc"
   CONFIG["CC_WRAPPER"] = ""
   CONFIG["PACKAGE"] = "ruby"
   CONFIG["BUILTIN_TRANSSRCS"] = " enc/trans/newline.c"
@@ -45,7 +45,7 @@ module RbConfig
   CONFIG["RUBY_SEARCH_PATH"] = ""
   CONFIG["UNIVERSAL_INTS"] = ""
   CONFIG["UNIVERSAL_ARCHNAMES"] = ""
-  CONFIG["configure_args"] = " '--enable-shared' '--program-suffix=32' '--with-soname=ruby32' '--with-ruby-version=3.2' '--with-mantype=doc' '--with-setjmp-type=_setjmp' '--enable-pthread' '--enable-ipv6' '--without-baseruby' '--without-bundled-libffi' '--disable-option-checking' '--with-compress-debug-sections=no' '--prefix=/usr/local' '--sysconfdir=/etc' '--mandir=/usr/local/man' '--infodir=/usr/local/info' '--localstatedir=/var' '--disable-silent-rules' '--disable-gtk-doc' 'CC=cc' 'CXX=c++' 'CFLAGS=-O2 -pipe' 'LDFLAGS=-L/usr/local/lib' 'CPPFLAGS=-DOPENSSL_NO_STATIC_ENGINE -I/usr/local/include' 'CXXFLAGS=-O2 -pipe'"
+  CONFIG["configure_args"] = " '--enable-shared' '--program-suffix=33' '--with-soname=ruby33' '--with-ruby-version=3.3' '--with-mantype=doc' '--with-setjmp-type=_setjmp' '--enable-pthread' '--enable-ipv6' '--without-baseruby' '--without-bundled-libffi' '--disable-option-checking' '--with-compress-debug-sections=no' '--prefix=/usr/local' '--sysconfdir=/etc' '--mandir=/usr/local/man' '--infodir=/usr/local/info' '--localstatedir=/var' '--disable-silent-rules' '--disable-gtk-doc' 'CC=cc' 'CXX=c++' 'CFLAGS=-O2 -pipe' 'LDFLAGS=-L/usr/local/lib' 'CPPFLAGS=-DOPENSSL_NO_STATIC_ENGINE -I/usr/local/include' 'CXXFLAGS=-O2 -pipe'"
   CONFIG["CONFIGURE"] = "configure"
   CONFIG["vendorarchdir"] = "$(vendorlibdir)/$(sitearch)"
   CONFIG["vendorlibdir"] = "$(vendordir)/$(ruby_version)"
@@ -55,7 +55,7 @@ module RbConfig
   CONFIG["sitedir"] = "$(rubylibprefix)/site_ruby"
   CONFIG["rubyarchdir"] = "$(rubylibdir)/$(arch)"
   CONFIG["rubylibdir"] = "$(rubylibprefix)/$(ruby_version)"
-  CONFIG["ruby_version"] = "3.2"
+  CONFIG["ruby_version"] = "3.3"
   CONFIG["sitearch"] = "$(arch)"
   CONFIG["arch"] = "riscv64-openbsd"
   CONFIG["sitearchincludedir"] = "$(includedir)/$(sitearch)"
@@ -64,13 +64,14 @@ module RbConfig
   CONFIG["archlibdir"] = "$(libdir)/$(arch)"
   CONFIG["libdirname"] = "libdir"
   CONFIG["RUBY_EXEC_PREFIX"] = "/usr/local"
-  CONFIG["RUBY_LIB_VERSION"] = "3.2"
+  CONFIG["RUBY_LIB_VERSION"] = "3.3"
   CONFIG["RUBY_LIB_VERSION_STYLE"] = ""
   CONFIG["RI_BASE_NAME"] = "ri"
   CONFIG["ridir"] = "$(datarootdir)/$(RI_BASE_NAME)"
   CONFIG["rubysitearchprefix"] = "$(rubylibprefix)/$(sitearch)"
   CONFIG["rubyarchprefix"] = "$(rubylibprefix)/$(arch)"
   CONFIG["MAKEFILES"] = "Makefile"
+  CONFIG["USE_LLVM_WINDRES"] = ""
   CONFIG["PLATFORM_DIR"] = ""
   CONFIG["COROUTINE_TYPE"] = "pthread"
   CONFIG["THREAD_MODEL"] = "pthread"
@@ -97,20 +98,20 @@ module RbConfig
   CONFIG["EXTDLDFLAGS"] = ""
   CONFIG["EXTLDFLAGS"] = ""
   CONFIG["strict_warnflags"] = ""
-  CONFIG["warnflags"] = "-Wall -Wextra -Wextra-tokens -Wdeprecated-declarations -Wdivision-by-zero -Wdiv-by-zero -Wimplicit-function-declaration -Wimplicit-int -Wmisleading-indentation -Wpointer-arith -Wshorten-64-to-32 -Wwrite-strings -Wold-style-definition -Wmissing-noreturn -Wno-cast-function-type -Wno-constant-logical-operand -Wno-long-long -Wno-missing-field-initializers -Wno-overlength-strings -Wno-parentheses-equality -Wno-self-assign -Wno-tautological-compare -Wno-unused-parameter -Wno-unused-value -Wunused-variable -Wundef"
+  CONFIG["warnflags"] = "-Wall -Wextra -Wextra-tokens -Wdeprecated-declarations -Wdivision-by-zero -Wdiv-by-zero -Wimplicit-function-declaration -Wimplicit-int -Wpointer-arith -Wshorten-64-to-32 -Wwrite-strings -Wold-style-definition -Wmissing-noreturn -Wno-cast-function-type -Wno-constant-logical-operand -Wno-long-long -Wno-missing-field-initializers -Wno-overlength-strings -Wno-parentheses-equality -Wno-self-assign -Wno-tautological-compare -Wno-unused-parameter -Wno-unused-value -Wunused-variable -Wmisleading-indentation -Wundef"
   CONFIG["debugflags"] = "-ggdb3"
   CONFIG["optflags"] = "-fno-fast-math"
   CONFIG["NULLCMD"] = ":"
   CONFIG["ENABLE_DEBUG_ENV"] = ""
   CONFIG["DLNOBJ"] = "dln.o"
-  CONFIG["INSTALL_STATIC_LIBRARY"] = "no"
+  CONFIG["RJIT_SUPPORT"] = "no"
   CONFIG["YJIT_OBJ"] = ""
   CONFIG["YJIT_LIBS"] = ""
   CONFIG["CARGO_BUILD_ARGS"] = ""
   CONFIG["YJIT_SUPPORT"] = "no"
   CONFIG["CARGO"] = ""
-  CONFIG["RUSTC"] = "no"
-  CONFIG["MJIT_SUPPORT"] = "yes"
+  CONFIG["RUSTC"] = "rustc"
+  CONFIG["INSTALL_STATIC_LIBRARY"] = "no"
   CONFIG["EXECUTABLE_EXTS"] = ""
   CONFIG["ARCHFILE"] = ""
   CONFIG["LIBRUBY_RELATIVE"] = "no"
@@ -159,9 +160,9 @@ module RbConfig
   CONFIG["DOXYGEN"] = ""
   CONFIG["DOT"] = ""
   CONFIG["MKDIR_P"] = "mkdir -p"
-  CONFIG["INSTALL_DATA"] = "/local/pobj/ruby-3.2.9/bin/install -c -m 644"
-  CONFIG["INSTALL_SCRIPT"] = "/local/pobj/ruby-3.2.9/bin/install -c -m 755"
-  CONFIG["INSTALL_PROGRAM"] = "/local/pobj/ruby-3.2.9/bin/install -c -s -m 755"
+  CONFIG["INSTALL_DATA"] = "/local/pobj/ruby-3.3.0/bin/install -c -m 644"
+  CONFIG["INSTALL_SCRIPT"] = "/local/pobj/ruby-3.3.0/bin/install -c -m 755"
+  CONFIG["INSTALL_PROGRAM"] = "/local/pobj/ruby-3.3.0/bin/install -c -s -m 755"
   CONFIG["SET_MAKE"] = ""
   CONFIG["LN_S"] = "ln -s"
   CONFIG["DLLWRAP"] = ""
@@ -169,9 +170,8 @@ module RbConfig
   CONFIG["ASFLAGS"] = ""
   CONFIG["ARFLAGS"] = "rcD "
   CONFIG["try_header"] = ""
-  CONFIG["CC_VERSION_MESSAGE"] = "OpenBSD clang version 19.1.7\nTarget: riscv64-unknown-openbsd7.8\nThread model: posix\nInstalledDir: /usr/bin"
+  CONFIG["CC_VERSION_MESSAGE"] = "OpenBSD clang version 16.0.6\nTarget: riscv64-unknown-openbsd7.5\nThread model: posix\nInstalledDir: /usr/bin"
   CONFIG["CC_VERSION"] = "$(CC) --version"
-  CONFIG["MJIT_CC"] = "/usr/bin/cc"
   CONFIG["CSRCFLAG"] = ""
   CONFIG["COUTFLAG"] = "-o "
   CONFIG["OUTFLAG"] = "-o "
@@ -187,7 +187,7 @@ module RbConfig
   CONFIG["STRIP"] = "strip -S -x"
   CONFIG["RANLIB"] = "ranlib"
   CONFIG["OBJDUMP"] = "objdump"
-  CONFIG["OBJCOPY"] = ":"
+  CONFIG["OBJCOPY"] = "objcopy"
   CONFIG["NM"] = "nm"
   CONFIG["LD"] = "ld"
   CONFIG["CXX"] = "c++"
@@ -196,7 +196,7 @@ module RbConfig
   CONFIG["CC"] = "cc"
   CONFIG["wasmoptflags"] = ""
   CONFIG["WASMOPT"] = ""
-  CONFIG["target_os"] = "openbsd7.8"
+  CONFIG["target_os"] = "openbsd7.5"
   CONFIG["target_vendor"] = "unknown"
   CONFIG["target_cpu"] = "riscv64"
   CONFIG["target"] = "$(target_cpu)-$(target_vendor)-$(target_os)"
@@ -204,10 +204,10 @@ module RbConfig
   CONFIG["host_vendor"] = "$(target_vendor)"
   CONFIG["host_cpu"] = "$(target_cpu)"
   CONFIG["host"] = "$(target)"
-  CONFIG["build_os"] = "openbsd7.8"
+  CONFIG["build_os"] = "openbsd7.5"
   CONFIG["build_vendor"] = "unknown"
   CONFIG["build_cpu"] = "riscv64"
-  CONFIG["build"] = "riscv64-unknown-openbsd7.8"
+  CONFIG["build"] = "riscv64-unknown-openbsd7.5"
   CONFIG["RUBY_VERSION_NAME"] = "$(RUBY_BASE_NAME)-$(ruby_version)"
   CONFIG["RUBYW_BASE_NAME"] = "rubyw"
   CONFIG["RUBY_BASE_NAME"] = "ruby"
@@ -247,7 +247,7 @@ module RbConfig
   CONFIG["libexecdir"] = "$(exec_prefix)/libexec"
   CONFIG["sbindir"] = "$(exec_prefix)/sbin"
   CONFIG["bindir"] = "$(exec_prefix)/bin"
-  CONFIG["program_transform_name"] = "s&$$&32&;s&^&&"
+  CONFIG["program_transform_name"] = "s&$$&33&;s&^&&"
   CONFIG["exec_prefix"] = "$(prefix)"
   CONFIG["PACKAGE_URL"] = ""
   CONFIG["PACKAGE_BUGREPORT"] = ""
