@@ -1,62 +1,73 @@
 # frozen_string_literal: true
-require 'rubygems/command'
-require 'rubygems/package'
-require 'rubygems/installer'
-require 'rubygems/version_option'
+
+require_relative "../command"
+require_relative "../package"
+require_relative "../installer"
+require_relative "../version_option"
 
 class Gem::Commands::PristineCommand < Gem::Command
   include Gem::VersionOption
 
   def initialize
-    super 'pristine',
-          'Restores installed gems to pristine condition from files located in the gem cache',
-          :version => Gem::Requirement.default,
-          :extensions => true,
-          :extensions_set => false,
-          :all => false
+    super "pristine",
+          "Restores installed gems to pristine condition from files located in the gem cache",
+          version: Gem::Requirement.default,
+          extensions: true,
+          extensions_set: false,
+          all: false
 
-    add_option('--all',
-               'Restore all installed gems to pristine',
-               'condition') do |value, options|
+    add_option("--all",
+               "Restore all installed gems to pristine",
+               "condition") do |value, options|
       options[:all] = value
     end
 
-    add_option('--skip=gem_name',
-               'used on --all, skip if name == gem_name') do |value, options|
+    add_option("--skip=gem_name",
+               "used on --all, skip if name == gem_name") do |value, options|
       options[:skip] ||= []
       options[:skip] << value
     end
 
-    add_option('--[no-]extensions',
-               'Restore gems with extensions',
-               'in addition to regular gems') do |value, options|
+    add_option("--[no-]extensions",
+               "Restore gems with extensions",
+               "in addition to regular gems") do |value, options|
       options[:extensions_set] = true
       options[:extensions]     = value
     end
 
-    add_option('--only-executables',
-               'Only restore executables') do |value, options|
+    add_option("--only-missing-extensions",
+               "Only restore gems with missing extensions") do |value, options|
+      options[:only_missing_extensions] = value
+    end
+
+    add_option("--only-executables",
+               "Only restore executables") do |value, options|
       options[:only_executables] = value
     end
 
-    add_option('--only-plugins',
-               'Only restore plugins') do |value, options|
+    add_option("--only-plugins",
+               "Only restore plugins") do |value, options|
       options[:only_plugins] = value
     end
 
-    add_option('-E', '--[no-]env-shebang',
-               'Rewrite executables with a shebang',
-               'of /usr/bin/env') do |value, options|
+    add_option("-E", "--[no-]env-shebang",
+               "Rewrite executables with a shebang",
+               "of /usr/bin/env") do |value, options|
       options[:env_shebang] = value
     end
 
-    add_option('-n', '--bindir DIR',
-               'Directory where executables are',
-               'located') do |value, options|
+    add_option("-i", "--install-dir DIR",
+               "Gem repository to get binstubs and plugins installed") do |value, options|
+      options[:install_dir] = File.expand_path(value)
+    end
+
+    add_option("-n", "--bindir DIR",
+               "Directory where executables are",
+               "located") do |value, options|
       options[:bin_dir] = File.expand_path(value)
     end
 
-    add_version_option('restore to', 'pristine condition')
+    add_version_option("restore to", "pristine condition")
   end
 
   def arguments # :nodoc:
@@ -64,7 +75,7 @@ class Gem::Commands::PristineCommand < Gem::Command
   end
 
   def defaults_str # :nodoc:
-    '--extensions'
+    "--extensions"
   end
 
   def description # :nodoc:
@@ -93,22 +104,24 @@ extensions will be restored.
 
   def execute
     specs = if options[:all]
-              Gem::Specification.map
+      Gem::Specification.map
 
-            # `--extensions` must be explicitly given to pristine only gems
-            # with extensions.
-            elsif options[:extensions_set] and
-                  options[:extensions] and options[:args].empty?
-              Gem::Specification.select do |spec|
-                spec.extensions and not spec.extensions.empty?
-              end
-            else
-              get_all_gem_names.sort.map do |gem_name|
-                Gem::Specification.find_all_by_name(gem_name, options[:version]).reverse
-              end.flatten
-            end
+    # `--extensions` must be explicitly given to pristine only gems
+    # with extensions.
+    elsif options[:extensions_set] &&
+          options[:extensions] && options[:args].empty?
+      Gem::Specification.select do |spec|
+        spec.extensions && !spec.extensions.empty?
+      end
+    elsif options[:only_missing_extensions]
+      Gem::Specification.select(&:missing_extensions?)
+    else
+      get_all_gem_names.sort.map do |gem_name|
+        Gem::Specification.find_all_by_name(gem_name, options[:version]).reverse
+      end.flatten
+    end
 
-    specs = specs.select{|spec| RUBY_ENGINE == spec.platform || Gem::Platform.local === spec.platform || spec.platform == Gem::Platform::RUBY }
+    specs = specs.select {|spec| spec.platform == RUBY_ENGINE || Gem::Platform.local === spec.platform || spec.platform == Gem::Platform::RUBY }
 
     if specs.to_a.empty?
       raise Gem::Exception,
@@ -123,22 +136,22 @@ extensions will be restored.
         next
       end
 
-      if options.has_key? :skip
+      if options.key? :skip
         if options[:skip].include? spec.name
           say "Skipped #{spec.full_name}, it was given through options"
           next
         end
       end
 
-      unless spec.extensions.empty? or options[:extensions] or options[:only_executables] or options[:only_plugins]
+      unless spec.extensions.empty? || options[:extensions] || options[:only_executables] || options[:only_plugins]
         say "Skipped #{spec.full_name}, it needs to compile an extension"
         next
       end
 
       gem = spec.cache_file
 
-      unless File.exist? gem or options[:only_executables] or options[:only_plugins]
-        require 'rubygems/remote_fetcher'
+      unless File.exist?(gem) || options[:only_executables] || options[:only_plugins]
+        require_relative "../remote_fetcher"
 
         say "Cached gem for #{spec.full_name} not found, attempting to fetch..."
 
@@ -158,26 +171,27 @@ extensions will be restored.
         if options.include? :env_shebang
           options[:env_shebang]
         else
-          install_defaults = Gem::ConfigFile::PLATFORM_DEFAULTS['install']
-          install_defaults.to_s['--env-shebang']
+          install_defaults = Gem::ConfigFile::PLATFORM_DEFAULTS["install"]
+          install_defaults.to_s["--env-shebang"]
         end
 
       bin_dir = options[:bin_dir] if options[:bin_dir]
+      install_dir = options[:install_dir] if options[:install_dir]
 
       installer_options = {
-        :wrappers => true,
-        :force => true,
-        :install_dir => spec.base_dir,
-        :env_shebang => env_shebang,
-        :build_args => spec.build_args,
-        :bin_dir => bin_dir,
+        wrappers: true,
+        force: true,
+        install_dir: install_dir || spec.base_dir,
+        env_shebang: env_shebang,
+        build_args: spec.build_args,
+        bin_dir: bin_dir,
       }
 
       if options[:only_executables]
         installer = Gem::Installer.for_spec(spec, installer_options)
         installer.generate_bin
       elsif options[:only_plugins]
-        installer = Gem::Installer.for_spec(spec)
+        installer = Gem::Installer.for_spec(spec, installer_options)
         installer.generate_plugins
       else
         installer = Gem::Installer.at(gem, installer_options)
