@@ -1,18 +1,18 @@
 # frozen_string_literal: true
-require_relative 'deprecate'
+
+require_relative "deprecate"
 
 ##
 # This module contains various utility methods as module methods.
 
 module Gem::Util
-
   ##
   # Zlib::GzipReader wrapper that unzips +data+.
 
   def self.gunzip(data)
-    require 'zlib'
-    require 'stringio'
-    data = StringIO.new(data, 'r')
+    require "zlib"
+    require "stringio"
+    data = StringIO.new(data, "r")
 
     gzip_reader = begin
                     Zlib::GzipReader.new(data)
@@ -29,9 +29,9 @@ module Gem::Util
   # Zlib::GzipWriter wrapper that zips +data+.
 
   def self.gzip(data)
-    require 'zlib'
-    require 'stringio'
-    zipped = StringIO.new(String.new, 'w')
+    require "zlib"
+    require "stringio"
+    zipped = StringIO.new(String.new, "w")
     zipped.set_encoding Encoding::BINARY
 
     Zlib::GzipWriter.wrap zipped do |io|
@@ -45,7 +45,7 @@ module Gem::Util
   # A Zlib::Inflate#inflate wrapper
 
   def self.inflate(data)
-    require 'zlib'
+    require "zlib"
     Zlib::Inflate.inflate data
   end
 
@@ -60,7 +60,7 @@ module Gem::Util
   # Invokes system, but silences all output.
 
   def self.silent_system(*command)
-    opt = {:out => IO::NULL, :err => [:child, :out]}
+    opt = { out: IO::NULL, err: [:child, :out] }
     if Hash === command.last
       opt.update(command.last)
       cmds = command[0...-1]
@@ -84,9 +84,13 @@ module Gem::Util
 
     here = File.expand_path directory
     loop do
-      Dir.chdir here, &block rescue Errno::EACCES
+      begin
+        Dir.chdir here, &block
+      rescue StandardError
+        Errno::EACCES
+      end
 
-      new_here = File.expand_path('..', here)
+      new_here = File.expand_path("..", here)
       return if new_here == here # toplevel
       here = new_here
     end
@@ -97,11 +101,7 @@ module Gem::Util
   # returning absolute paths to the matching files.
 
   def self.glob_files_in_dir(glob, base_path)
-    if RUBY_VERSION >= "2.5"
-      Dir.glob(glob, base: base_path).map! {|f| File.expand_path(f, base_path) }
-    else
-      Dir.glob(File.expand_path(glob, base_path))
-    end
+    Dir.glob(glob, base: base_path).map! {|f| File.expand_path(f, base_path) }
   end
 
   ##
@@ -109,11 +109,10 @@ module Gem::Util
   # comes with a leading slash.
 
   def self.correct_for_windows_path(path)
-    if path[0].chr == '/' && path[1].chr =~ /[a-z]/i && path[2].chr == ':'
+    if path[0].chr == "/" && path[1].chr.match?(/[a-z]/i) && path[2].chr == ":"
       path[1..-1]
     else
       path
     end
   end
-
 end
