@@ -5,6 +5,10 @@ require 'pp'
 
 require_relative 'color'
 
+class ::Thread
+  attr_accessor :debug_thread_client
+end
+
 module DEBUGGER__
   M_INSTANCE_VARIABLES = method(:instance_variables).unbind
   M_INSTANCE_VARIABLE_GET = method(:instance_variable_get).unbind
@@ -14,6 +18,7 @@ module DEBUGGER__
   M_RESPOND_TO_P = method(:respond_to?).unbind
   M_METHOD = method(:method).unbind
   M_OBJECT_ID = method(:object_id).unbind
+  M_NAME = method(:name).unbind
 
   module SkipPathHelper
     def skip_path?(path)
@@ -47,12 +52,7 @@ module DEBUGGER__
 
   class ThreadClient
     def self.current
-      if thc = Thread.current[:DEBUGGER__ThreadClient]
-        thc
-      else
-        thc = SESSION.get_thread_client
-        Thread.current[:DEBUGGER__ThreadClient] = thc
-      end
+      Thread.current.debug_thread_client ||= SESSION.get_thread_client
     end
 
     include Color
@@ -468,10 +468,14 @@ module DEBUGGER__
       if file_lines = frame.file_lines
         frame_line = frame.location.lineno - 1
 
-        lines = file_lines.map.with_index do |e, i|
-          cur = i == frame_line ? '=>' : '  '
-          line = colorize_dim('%4d|' % (i+1))
-          "#{cur}#{line} #{e}"
+        if CONFIG[:no_lineno]
+          lines = file_lines
+        else
+          lines = file_lines.map.with_index do |e, i|
+            cur = i == frame_line ? '=>' : '  '
+            line = colorize_dim('%4d|' % (i+1))
+            "#{cur}#{line} #{e}"
+          end
         end
 
         unless start_line
@@ -607,12 +611,17 @@ module DEBUGGER__
 
     def get_consts expr = nil, only_self: false, &block
       if expr && !expr.empty?
-        _self = frame_eval(expr)
-        if M_KIND_OF_P.bind_call(_self, Module)
-          iter_consts _self, &block
-          return
+        begin
+          _self = frame_eval(expr, re_raise: true)
+        rescue Exception
+          # ignore
         else
-          raise "#{_self.inspect} (by #{expr}) is not a Module."
+          if M_KIND_OF_P.bind_call(_self, Module)
+            iter_consts _self, &block
+            return
+          else
+            puts "#{_self.inspect} (by #{expr}) is not a Module."
+          end
         end
       elsif _self = current_frame&.self
         cs = {}
@@ -852,8 +861,18 @@ module DEBUGGER__
     class SuspendReplay < Exception
     end
 
+    if ::Fiber.respond_to?(:blocking)
+      private def fiber_blocking
+        ::Fiber.blocking{yield}
+      end
+    else
+      private def fiber_blocking
+        yield
+      end
+    end
+
     def wait_next_action
-      wait_next_action_
+      fiber_blocking{wait_next_action_}
     rescue SuspendReplay
       replay_suspend
     end
@@ -1038,13 +1057,8 @@ module DEBUGGER__
           when :call
             result = frame_eval(eval_src)
           when :irb
-            require 'irb' # prelude's binding.irb doesn't have show_code option
-            begin
-              result = frame_eval('binding.irb(show_code: false)', binding_location: true)
-            ensure
-              # workaround: https://github.com/ruby/debug/issues/308
-              Reline.prompt_proc = nil if defined? Reline
-            end
+            require_relative "irb_integration"
+            activate_irb_integration
           when :display, :try_display
             failed_results = []
             eval_src.each_with_index{|src, i|
@@ -1230,7 +1244,15 @@ module DEBUGGER__
     rescue SuspendReplay, SystemExit, Interrupt
       raise
     rescue Exception => e
-      pp ["DEBUGGER Exception: #{__FILE__}:#{__LINE__}", e, e.backtrace]
+      STDERR.puts e.cause.inspect
+      STDERR.puts e.inspect
+      Thread.list.each{|th|
+        STDERR.puts "@@@ #{th}"
+        th.backtrace.each{|b|
+          STDERR.puts " > #{b}"
+        }
+      }
+      p ["DEBUGGER Exception: #{__FILE__}:#{__LINE__}", e, e.backtrace]
       raise
     ensure
       @returning = false
@@ -1292,10 +1314,14 @@ module DEBUGGER__
               frame._callee = b.eval('__callee__')
             end
           }
-          @log << frames
+          append(frames)
         }
       end
 
+      def append frames
+        @log << frames
+      end
+
       def enable
         unless @tp_recorder.enabled?
           @log.clear
