@@ -1,4 +1,4 @@
 require 'mkmf'
 $INCFLAGS << " -I$(top_srcdir)" if $extmk
-append_cflags ['-std=c99']
+append_cflags ['-std=gnu99']
 create_makefile 'rbs_extension'
